#[repr(i32)]pub enum ClaimType {
Unspecified = 0,
SendToCosmos = 1,
BatchSendToEth = 2,
Erc20Deployed = 3,
LogicCallExecuted = 4,
ValsetUpdated = 5,
}Expand description
ClaimType is the cosmos type of an event from the counterpart chain that can be handled
Variants
Unspecified = 0
An unspecified claim type
SendToCosmos = 1
A claim for a SendToCosmos transaction
BatchSendToEth = 2
A claim for when batches are relayed
Erc20Deployed = 3
A claim for when an erc20 contract has been deployed
LogicCallExecuted = 4
A claim for when a logic call has been executed
ValsetUpdated = 5
A claim for when a valset update has happened
Implementations
Sourceimpl ClaimType
impl ClaimType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.