LastObservedEthereumBlockHeight

Struct LastObservedEthereumBlockHeight 

pub struct LastObservedEthereumBlockHeight {
    pub cosmos_block_height: u64,
    pub ethereum_block_height: u64,
}
LastObservedEthereumBlockHeight stores the last observed Ethereum block height along with the Cosmos block height that it was observed at. These two numbers can be used to project outward and always produce batches with timeouts in the future even if no Ethereum block height has been relayed for a long time

Fields

cosmos_block_height: u64ethereum_block_height: u64