MsgConfirmBatch

Struct MsgConfirmBatch 

pub struct MsgConfirmBatch {
    pub nonce: u64,
    pub token_contract: String,
    pub eth_signer: String,
    pub orchestrator: String,
    pub signature: String,
}
MsgConfirmBatch When validators observe a MsgRequestBatch they form a batch by ordering transactions currently in the txqueue in order of highest to lowest fee, cutting off when the batch either reaches a hardcoded maximum size (to be decided, probably around 100) or when transactions stop being profitable (TODO determine this without nondeterminism) This message includes the batch as well as an Ethereum signature over this batch by the validator

Fields

nonce: u64token_contract: Stringeth_signer: Stringorchestrator: Stringsignature: String