pub struct QueryLastObservedEthNonceRequest {
pub use_v1_key: bool,
}Expand description
QueryLastObservedEthNonceRequest defines the request for getting the event nonce of the last applied Ethereum Event on the bridge. Note that this is likely to lag the last executed event a little due to 1. Ethereum Finality and 2. Consensus mirroring the Ethereum state
Fields
use_v1_key: boolindicates whether to search for store data using the old Gravity v1 key “LastObservedEventNonceKey” Note that queries before the Mercury upgrade at height 1282013 must set this to true