pub struct QueryClient<T> { /* private fields */ }Expand description
Query defines the gRPC querier service.
Implementations
Sourceimpl QueryClient<Channel>
impl QueryClient<Channel>
Sourceimpl<T> QueryClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> QueryClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> QueryClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>,
<T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn params(
&mut self,
request: impl IntoRequest<QueryParamsRequest>,
) -> Result<Response<QueryParamsResponse>, Status>
pub async fn params( &mut self, request: impl IntoRequest<QueryParamsRequest>, ) -> Result<Response<QueryParamsResponse>, Status>
Params returns the current module parameters (decided by governance)
Sourcepub async fn auction_period(
&mut self,
request: impl IntoRequest<QueryAuctionPeriodRequest>,
) -> Result<Response<QueryAuctionPeriodResponse>, Status>
pub async fn auction_period( &mut self, request: impl IntoRequest<QueryAuctionPeriodRequest>, ) -> Result<Response<QueryAuctionPeriodResponse>, Status>
AuctionPeriod returns the current active auction period, or a future one if no period is active
Sourcepub async fn auctions(
&mut self,
request: impl IntoRequest<QueryAuctionsRequest>,
) -> Result<Response<QueryAuctionsResponse>, Status>
pub async fn auctions( &mut self, request: impl IntoRequest<QueryAuctionsRequest>, ) -> Result<Response<QueryAuctionsResponse>, Status>
Auctions returns all current active auctions
Sourcepub async fn auction_by_id(
&mut self,
request: impl IntoRequest<QueryAuctionByIdRequest>,
) -> Result<Response<QueryAuctionByIdResponse>, Status>
pub async fn auction_by_id( &mut self, request: impl IntoRequest<QueryAuctionByIdRequest>, ) -> Result<Response<QueryAuctionByIdResponse>, Status>
AuctionById returns an open auction given by its id
Sourcepub async fn auction_by_denom(
&mut self,
request: impl IntoRequest<QueryAuctionByDenomRequest>,
) -> Result<Response<QueryAuctionByDenomResponse>, Status>
pub async fn auction_by_denom( &mut self, request: impl IntoRequest<QueryAuctionByDenomRequest>, ) -> Result<Response<QueryAuctionByDenomResponse>, Status>
AuctionByDenom returns an open auction given by its denom
Sourcepub async fn all_auctions_by_bidder(
&mut self,
request: impl IntoRequest<QueryAllAuctionsByBidderRequest>,
) -> Result<Response<QueryAllAuctionsByBidderResponse>, Status>
pub async fn all_auctions_by_bidder( &mut self, request: impl IntoRequest<QueryAllAuctionsByBidderRequest>, ) -> Result<Response<QueryAllAuctionsByBidderResponse>, Status>
AllAuctionsByBidder returns all open auctions with the given highest bidder address
Sourcepub async fn auction_pool(
&mut self,
request: impl IntoRequest<QueryAuctionPoolRequest>,
) -> Result<Response<QueryAuctionPoolResponse>, Status>
pub async fn auction_pool( &mut self, request: impl IntoRequest<QueryAuctionPoolRequest>, ) -> Result<Response<QueryAuctionPoolResponse>, Status>
AuctionPool returns the auction pool account address and the tokens which will be up for auction next, (but does not return any amounts from auctions with no bidder)